==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/zh_HK.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "您不能移除自己的閱讀權限。",
    "Team folders" : "團隊資料夾",
    "Admin configured folders shared with everyone in a team" : "管理員設定，與團隊中所有人共用的資料夾",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "管理員已配置資料夾與團隊中的每個人共用。\n\n可以在管理設定中的「團隊資料夾」配置。\n\n建立資料夾後，管理員可讓一個或多個團隊存取資料夾，控制他們的寫入/分享權限，並為資料夾指定配額。\n自 Hub 10/Nextcloud 31 起，管理員必須是團隊的一員，才能指派團隊資料夾。",
    "Unset" : "解除設置",
    "Denied (Inherited permission)" : "拒絕（繼承權限）",
    "Allowed (Inherited permission)" : "允許（繼承權限）",
    "Denied" : "拒絕",
    "Allowed" : "允許",
    "Access denied" : "拒絕存取",
    "Access allowed" : "允許存取",
    "Inherit permission" : "繼承權限",
    "Deny" : "拒絕",
    "Allow" : "允許",
    "Group" : "群組",
    "Team" : "團隊",
    "Team folder" : "團隊資料夾",
    "Read" : "已讀",
    "Write" : "寫入",
    "Create" : "建立",
    "Delete" : "刪除",
    "Share" : "分享",
    "You" : "您",
    "Remove access rule" : "移除存取規則",
    "Add advanced permission rule" : "添加高級權限規則",
    "Select a user or group" : "選擇用戶或群組",
    "Open Team folder" : "開啟團隊資料夾",
    "Permission denied. User does not have sufficient permissions." : "權限被拒絕。用戶權限不足。",
    "Unexpected status from server" : "伺服器狀態異常",
    "List of Team folders." : "團隊資料夾清單。",
    "No Team folders yet" : "尚無團隊資料夾",
    "Team folders will show up here" : "團隊資料夾將會在此顯示",
    "Add group" : "新增群組",
    "Default" : "默認",
    "Unlimited" : "無限制",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "您確定要刪除「{folderName}」和裡面所有的檔案嗎？此操作無法撤消",
    "Delete \"{folderName}\"?" : "刪除「{folderName}」？",
    "Team folder admin delegation" : "團隊資料夾委派管理員",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud 允許您將團隊資料夾的管理權限委派給非管理員用戶。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "請在下方指定將被允許管理團隊資料夾並使用其 API/REST 的群組。",
    "They will have access to all Team folders." : "他們可以存取所有的團隊資料夾。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "請在下方指定將僅被允許管理團隊資料夾並使用其 API/REST 的群組。",
    "They will only have access to Team folders for which they have advanced permissions." : "他們僅能存取他們擁有進階權限的團隊資料夾。",
    "Group or team" : "群組或團隊",
    "Sort by number of groups or teams that have access to this folder" : "按可存取此資料夾的群組數量排序",
    "Sort by number of groups that have access to this folder" : "按可存取此資料夾的群組數量排序",
    "Folder name" : "資料夾名稱",
    "Quota" : "容量限額",
    "Advanced Permissions" : "高級權限",
    "Pagination of team folders" : "團隊資料夾分頁",
    "Previous" : "上一",
    "Next" : "下一",
    "User" : "用戶",
    "Unknown" : "不詳",
    "Users/groups that can manage" : "可以管理以下內容的用戶/群組",
    "None" : "無",
    "No other groups or teams available" : "沒有其他群組或團隊了",
    "No other groups available" : "沒有其他群組了",
    "{displayName} (team)" : "{displayName}（團隊）",
    "Add group or team" : "添加群組或團隊",
    "{size} used" : "已使用 {size}",
    "Other …" : "其它 ...",
    "You can not remove your own read permission." : "您不能移除自己的閱讀權限。",
    "Group folders" : "群組資料夾",
    "Admin configured folders shared with everyone in a group" : "管理員配置的資料夾，可與群組中的所有人共享",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "管理員設定資料夾與群組中的每個人共用。\n\n可以在管理設定中的「群組資料夾」設定。\n\n建立資料夾之後，管理員可以設定讓一或多個群組存取。控制其寫入／分享權限並指定該資料夾的限額。",
    "Group folder" : "群組資料夾",
    "Open group folder" : "開啟群組資料夾",
    "List of group folders." : "群組資料夾清單。",
    "No group folders yet" : "尚無群組資料夾",
    "Group folders will show up here" : "群組資料夾將會在此顯示",
    "Group folder admin delegation" : "群組資料夾委派管理員",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud 允許您將群組資料夾的管理權限委派給非管理員用戶。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "請在下方指定將被允許管理群組資料夾並使用其 API/REST 的群組。",
    "They will have access to all group folders." : "他們可以存取所有的群組資料夾。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "請在下方指定將僅被允許管理群組資料夾並使用其 API/REST 的群組。",
    "They will only have access to group folders for which they have advanced permissions." : "他們僅能存取他們擁有進階權限的群組資料夾。",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "管理員設定，與團隊中所有人共用的資料夾。\n\n可以在管理設定中的「團隊資料夾」設定。\n\n建立資料夾之後，管理員可以設定讓一或多個團隊存取。控制其寫入／分享權限並指定該資料夾的限額。"
},
"nplurals=1; plural=0;");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/zh_HK.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "您不能移除自己的閱讀權限。",
    "Team folders" : "團隊資料夾",
    "Unset" : "解除設置",
    "Denied (Inherited permission)" : "拒絕（繼承權限）",
    "Allowed (Inherited permission)" : "允許（繼承權限）",
    "Denied" : "拒絕",
    "Allowed" : "允許",
    "Access denied" : "拒絕存取",
    "Access allowed" : "允許存取",
    "Inherit permission" : "繼承權限",
    "Deny" : "拒絕",
    "Allow" : "允許",
    "Group" : "群組",
    "Team" : "團隊",
    "Team folder" : "團隊資料夾",
    "Read" : "已讀",
    "Write" : "寫入",
    "Create" : "建立",
    "Delete" : "刪除",
    "Share" : "分享",
    "You" : "您",
    "Remove access rule" : "移除存取規則",
    "Add advanced permission rule" : "添加高級權限規則",
    "Select a user or group" : "選擇用戶或群組",
    "Open Team folder" : "開啟團隊資料夾",
    "Permission denied. User does not have sufficient permissions." : "權限被拒絕。用戶權限不足。",
    "Unexpected status from server" : "伺服器狀態異常",
    "List of Team folders." : "團隊資料夾清單。",
    "No Team folders yet" : "尚無團隊資料夾",
    "Team folders will show up here" : "團隊資料夾將會在此顯示",
    "Add group" : "新增群組",
    "Default" : "默認",
    "Unlimited" : "無限制",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "您確定要刪除「{folderName}」和裡面所有的檔案嗎？此操作無法撤消",
    "Delete \"{folderName}\"?" : "刪除「{folderName}」？",
    "Team folder admin delegation" : "團隊資料夾委派管理員",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud 允許您將團隊資料夾的管理權限委派給非管理員用戶。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "請在下方指定將被允許管理團隊資料夾並使用其 API/REST 的群組。",
    "They will have access to all Team folders." : "他們可以存取所有的團隊資料夾。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "請在下方指定將僅被允許管理團隊資料夾並使用其 API/REST 的群組。",
    "They will only have access to Team folders for which they have advanced permissions." : "他們僅能存取他們擁有進階權限的團隊資料夾。",
    "Group or team" : "群組或團隊",
    "Sort by number of groups or teams that have access to this folder" : "按可存取此資料夾的群組數量排序",
    "Sort by number of groups that have access to this folder" : "按可存取此資料夾的群組數量排序",
    "Folder name" : "資料夾名稱",
    "Quota" : "容量限額",
    "Advanced Permissions" : "高級權限",
    "Pagination of team folders" : "團隊資料夾分頁",
    "Previous" : "上一",
    "Next" : "下一",
    "User" : "用戶",
    "Unknown" : "不詳",
    "Users/groups that can manage" : "可以管理以下內容的用戶/群組",
    "None" : "無",
    "No other groups or teams available" : "沒有其他群組或團隊了",
    "No other groups available" : "沒有其他群組了",
    "{displayName} (team)" : "{displayName}（團隊）",
    "Add group or team" : "添加群組或團隊",
    "{size} used" : "已使用 {size}",
    "Other …" : "其它 ...",
    "You can not remove your own read permission." : "您不能移除自己的閱讀權限。",
    "Group folders" : "群組資料夾",
    "Admin configured folders shared with everyone in a group" : "管理員配置的資料夾，可與群組中的所有人共享",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "管理員設定資料夾與群組中的每個人共用。\n\n可以在管理設定中的「群組資料夾」設定。\n\n建立資料夾之後，管理員可以設定讓一或多個群組存取。控制其寫入／分享權限並指定該資料夾的限額。",
    "Group folder" : "群組資料夾",
    "Open group folder" : "開啟群組資料夾",
    "List of group folders." : "群組資料夾清單。",
    "No group folders yet" : "尚無群組資料夾",
    "Group folders will show up here" : "群組資料夾將會在此顯示",
    "Group folder admin delegation" : "群組資料夾委派管理員",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud 允許您將群組資料夾的管理權限委派給非管理員用戶。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "請在下方指定將被允許管理群組資料夾並使用其 API/REST 的群組。",
    "They will have access to all group folders." : "他們可以存取所有的群組資料夾。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "請在下方指定將僅被允許管理群組資料夾並使用其 API/REST 的群組。",
    "They will only have access to group folders for which they have advanced permissions." : "他們僅能存取他們擁有進階權限的群組資料夾。",
    "Admin configured folders shared with everyone in a team" : "管理員設定，與團隊中所有人共用的資料夾",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "管理員設定，與團隊中所有人共用的資料夾。\n\n可以在管理設定中的「團隊資料夾」設定。\n\n建立資料夾之後，管理員可以設定讓一或多個團隊存取。控制其寫入／分享權限並指定該資料夾的限額。",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "管理員已配置資料夾與團隊中的每個人共用。\n\n可以在管理設定中的「團隊資料夾」配置。\n\n建立資料夾後，管理員可讓一個或多個團隊存取資料夾，控制他們的寫入/分享權限，並為資料夾指定配額。\n自 Hub 10/Nextcloud 31 起，管理員必須是團隊的一員，才能指派團隊資料夾。"
},
"nplurals=1; plural=0;");
